## Change Log

### 0.0.1 (17.2.2023.)
- Inital release

### 0.0.2 (17.2.2023.)
- Fixed markdown files

### 0.0.3 (17.2.2023.)
- Fixed CHANELOG.md missing in packaged file
- Remove unnecessary files

### 0.0.4 (17.2.2023.)
- Fixed unnecessary install_requires

### 0.0.5 (23.2.2023.)
- Class now accepts python list with setup values, hence no longer logic for loading file into memory
- Added carTitle property which holds car name ment for displaying in UI